@@ -372,8 +372,9 @@ class Client(object):
         return resp.json()["data"]
 
     def ohlcv(
-        self, tickers:str or list, begin:dt.datetime or str, end:dt.datetime or str=None, 
-        interval:str="1day", warning:bool=True,
+        self, tickers:str or list, begin:dt.datetime or str, 
+        end:None or dt.datetime or str=None, interval:str="1day", 
+        warning:bool=True,
     ) -> pd.DataFrame:
         """Query historic OHLC(V) data for a ticker or list of tickers 
 
@@ -451,7 +452,6 @@ class Client(object):
             for path in paths:
                 url = self._request("get", path)
                 resp = self.session.request("get", url)
-
                 # Handle timeout response by sleeping function
                 if resp.status_code == 200:
                     pass
@@ -459,11 +459,17 @@ class Client(object):
                     logging.debug("Server requires 10 second timeout")
                     time.sleep(11)
                     logging.debug("Re-establishing stream . . . ")
-                    resp = self.session.request("get", url)
+                    try:
+                        resp = self.session.request("get", url)
+                    except requests.exceptions.ConnectionError:
+                        time.sleep(180)
+                        self.session = self._session()
+                        resp = self.session.request("get", url)
                     if resp.status_code == 429:
                         logging.debug("Server requires hard timeout: 3 minute delay.")
                         time.sleep(180)
                         logging.debug("Re-establishing stream . . . ")
+                        self.session = self._session() # Reset session to avoid API throttle
                         resp = self.session.request("get", url)
                         if resp.status_code == 429:
                             logging.debug("Server requires hard timeout: 5 minute delay.")
